import { useEffect } from 'react';
import { queryApi } from '../store';
import { create } from 'zustand';
import { toast } from 'react-toastify';
import { vipFeatureList } from '../constants';
import { usePayModalStore, PayModal } from '../pay-modal/PayModal';
import { useShallow } from 'zustand/react/shallow';
interface VipStore {
  vipList: any[];
  setVipList: (vipList: any[]) => void;
  init: () => Promise<void>;
  vipInfo?: {
    level: string;
    startDate: string;
    endDate: string;
    category: string;
  };
  setVipInfo: (vipInfo: any) => void;
}

export const useVipStore = create<VipStore>((set) => ({
  vipList: [],
  setVipList: (vipList: any[]) => set({ vipList }),
  vipInfo: {
    level: '',
    startDate: '',
    endDate: '',
    category: '',
  },
  setVipInfo: (vipInfo: any) => set({ vipInfo }),
  init: async () => {
    const res = await queryApi.getMeVipList();
    if (res.code === 200) {
      const list = res.data.list || [];
      set({ vipList: list });
      const vipCenterInfo = list.find((item: any) => item.category === 'center');
      set({ vipInfo: vipCenterInfo });
    } else {
      toast.error(res.message || '获取VIP列表失败');
    }
  },
}));

export const VipInfo = () => {
  const store = useVipStore();
  const payModalStore = usePayModalStore(
    useShallow((state) => {
      return { setOpen: state.setOpen, setMoney: state.setMoney };
    }),
  );
  useEffect(() => {
    store.init();
  }, []);

  const vipPlans = [
    {
      type: '普通方案',
      level: 'free',
      background: 'bg-white',
      textColor: 'text-gray-800',
      description: '满足简单的部署应用需求',
      price: '免费',
      buttonText: '进入部署中心',
      buttonClass: 'bg-white border border-blue-500 text-blue-500 hover:bg-blue-50',
    },
    {
      type: '支持会员',
      background: 'bg-blue-50',
      level: 'love',
      textColor: 'text-gray-800',
      description: '可以部署更多应用和更多增值服务',
      price: '1.0',
      buttonText: '立即开通',
      buttonClass: 'bg-blue-500 text-white hover:bg-blue-600',
    },
    {
      type: '高级会员',
      background: 'bg-gray-800',
      level: 'vip',
      textColor: 'text-amber-200',
      description: '应用定制和专属支持',
      price: '5.0',
      buttonText: '立即开通',
      buttonClass: 'bg-amber-100 text-gray-800 hover:bg-amber-200',
    },
  ];
  const onBuyVip = (clickLevel: string) => {
    const currentLevel = store.vipInfo?.level || 'free';
    const currentLevelNumber = vipFeatureList.find((item) => item.level === currentLevel)?.levelNumber || 0;
    const clickLevelNumber = vipFeatureList.find((item) => item.level === clickLevel)?.levelNumber || 0;

    if (clickLevel === 'free') {
      window.location.href = '/root/center/';
      return;
    }
    if (clickLevelNumber <= currentLevelNumber) {
      toast.info('您已经是该会员等级');
      return;
    }
    // 打开支付弹窗
    payModalStore.setOpen(true);
    payModalStore.setMoney(clickLevelNumber);
    return;
  };
  return (
    <div className='w-full flex flex-col items-center py-10 px-4 bg-gray-50 h-full scrollbar'>
      {/* 封面部分 */}
      <div className='w-full max-w-6xl bg-gradient-to-r from-blue-600 to-indigo-800 rounded-xl p-10 mb-16 text-white shadow-lg'>
        <div className='max-w-3xl'>
          <h1 className='text-4xl md:text-5xl font-bold mb-4'>一切为了快速运行</h1>
          <p className='text-xl md:text-2xl font-light opacity-90'>方便部署轻量级的网页app应用，并可以随时随地访问</p>
        </div>
      </div>

      <h1 className='text-3xl font-bold mb-16 text-gray-800'>功能权益对比</h1>

      <div className='flex flex-wrap justify-center gap-6 w-full max-w-6xl'>
        {vipPlans.map((plan, index) => {
          const vipFeatures = vipFeatureList.find((item) => item.level === plan.level);
          const planIsVip = plan.level === 'vip';
          const isActive = plan.level === store.vipInfo?.level;
          let planButtonText = plan.buttonText;
          if (isActive && plan.level !== 'free') {
            planButtonText = '已开通';
          }
          if (!isActive && plan.level === 'vip' && store.vipInfo?.level === 'love') {
            planButtonText = '升级';
          }

          return (
            <div key={index} className={`${plan.background} rounded-lg p-8 flex flex-col items-center w-full max-w-xs`}>
              <h2 className={`text-3xl font-bold mb-4 ${plan.textColor}`}>{plan.level}</h2>
              <p className={`text-center mb-8 ${plan.textColor}`}>{plan.description}</p>

              <div className={`flex items-end mb-8 ${plan.textColor}`}>
                <span className='text-xl'>低至</span>
                <span className='text-6xl font-semibold mx-2'>{plan.price}</span>
                {plan.price !== '免费' && <span className='text-xl'>元/月</span>}
              </div>

              <button
                className={`py-3 px-6 w-full rounded-md font-medium cursor-pointer transition-colors ${plan.buttonClass}`}
                onClick={() => onBuyVip(plan.level)}>
                {planButtonText}
              </button>
              <div className='flex flex-col items-start py-4'>
                {vipFeatures?.features.map((feature, index) => (
                  <div key={index} className='flex items-center mb-2'>
                    <span className={`${planIsVip ? 'text-white' : 'text-gray-600'} mr-2`}>{index + 1}.</span>
                    <span className={`${planIsVip ? 'text-white' : 'text-gray-800'}`}>{feature.title}</span>
                  </div>
                ))}
              </div>
            </div>
          );
        })}
      </div>
      <PayModal />
    </div>
  );
};
